# biblemateai

BibleMate AI Web Application - Web UI based on the work at https://github.com/eliranwong/biblemate

# Development in Progress ...

Install for testing:

> pip install --upgrade biblemateweb

Run:

> biblemateweb